@@ -39,8 +39,8 @@ impl Db {
     /// Creates a new store at the specified path, or opens the store if it already exists.
     /// The base_url is the domain where the db will be hosted, e.g. http://localhost/
     /// It is used for distinguishing locally defined items from externally defined ones.
-    pub fn init<P: AsRef<std::path::Path>>(path: P, base_url: String) -> AtomicResult<Db> {
-        let db = sled::open(path).map_err(|e|format!("Failed opening DB at this location. Is another instance of Atomic Server running? {}", e))?;
+    pub fn init(path: &std::path::Path, base_url: String) -> AtomicResult<Db> {
+        let db = sled::open(path).map_err(|e|format!("Failed opening DB at this location: {:?} . Is another instance of Atomic Server running? {}", path, e))?;
         let resources = db.open_tree("resources").map_err(|e|format!("Failed building resources. Your DB might be corrupt. Go back to a previous version and export your data. {}", e))?;
         let index_vals = db.open_tree("index_vals")?;
         let store = Db {
